@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -22,7 +22,7 @@
 
 /* Get the name of the audio device we use for output */
 
-#if SDL_AUDIO_DRIVER_NETBSD || SDL_AUDIO_DRIVER_OSS || SDL_AUDIO_DRIVER_SUNAUDIO
+#if defined(SDL_AUDIO_DRIVER_NETBSD) || defined(SDL_AUDIO_DRIVER_OSS) || defined(SDL_AUDIO_DRIVER_SUNAUDIO)
 
 #include <fcntl.h>
 #include <sys/types.h>
@@ -34,9 +34,9 @@
 
 #ifndef _PATH_DEV_DSP
 #if defined(__NETBSD__) || defined(__OPENBSD__)
-#define _PATH_DEV_DSP  "/dev/audio"
+#define _PATH_DEV_DSP "/dev/audio"
 #else
-#define _PATH_DEV_DSP  "/dev/dsp"
+#define _PATH_DEV_DSP "/dev/dsp"
 #endif
 #endif
 #ifndef _PATH_DEV_DSP24
@@ -46,8 +46,7 @@
 #define _PATH_DEV_AUDIO "/dev/audio"
 #endif
 
-static void
-test_device(const int iscapture, const char *fname, int flags, int (*test) (int fd))
+static void test_device(const int iscapture, const char *fname, int flags, int (*test)(int fd))
 {
     struct stat sb;
     if ((stat(fname, &sb) == 0) && (S_ISCHR(sb.st_mode))) {
@@ -65,40 +64,40 @@ test_device(const int iscapture, const char *fname, int flags, int (*test) (int
                  * information,  making this information inaccessible at
                  * enumeration time
                  */
-                SDL_AddAudioDevice(iscapture, fname, NULL, (void *) (uintptr_t) dummyhandle);
+                SDL_AddAudioDevice(iscapture, fname, NULL, (void *)(uintptr_t)dummyhandle);
             }
         }
     }
 }
 
-static int
-test_stub(int fd)
+static int test_stub(int fd)
 {
     return 1;
 }
 
-static void
-SDL_EnumUnixAudioDevices_Internal(const int iscapture, const int classic, int (*test)(int))
+static void SDL_EnumUnixAudioDevices_Internal(const int iscapture, const int classic, int (*test)(int))
 {
     const int flags = iscapture ? OPEN_FLAGS_INPUT : OPEN_FLAGS_OUTPUT;
     const char *audiodev;
     char audiopath[1024];
 
-    if (test == NULL)
+    if (!test) {
         test = test_stub;
+    }
 
     /* Figure out what our audio device is */
-    if (((audiodev = SDL_getenv("SDL_PATH_DSP")) == NULL) &&
-        ((audiodev = SDL_getenv("AUDIODEV")) == NULL)) {
+    audiodev = SDL_getenv("SDL_PATH_DSP");
+    if (!audiodev) {
+        audiodev = SDL_getenv("AUDIODEV");
+    }
+    if (!audiodev) {
         if (classic) {
             audiodev = _PATH_DEV_AUDIO;
         } else {
             struct stat sb;
 
             /* Added support for /dev/sound/\* in Linux 2.4 */
-            if (((stat("/dev/sound", &sb) == 0) && S_ISDIR(sb.st_mode))
-                && ((stat(_PATH_DEV_DSP24, &sb) == 0)
-                    && S_ISCHR(sb.st_mode))) {
+            if (((stat("/dev/sound", &sb) == 0) && S_ISDIR(sb.st_mode)) && ((stat(_PATH_DEV_DSP24, &sb) == 0) && S_ISCHR(sb.st_mode))) {
                 audiodev = _PATH_DEV_DSP24;
             } else {
                 audiodev = _PATH_DEV_DSP;
@@ -110,16 +109,15 @@ SDL_EnumUnixAudioDevices_Internal(const int iscapture, const int classic, int (*
     if (SDL_strlen(audiodev) < (sizeof(audiopath) - 3)) {
         int instance = 0;
         while (instance <= 64) {
-            SDL_snprintf(audiopath, SDL_arraysize(audiopath),
-                         "%s%d", audiodev, instance);
+            (void)SDL_snprintf(audiopath, SDL_arraysize(audiopath),
+                               "%s%d", audiodev, instance);
             instance++;
             test_device(iscapture, audiopath, flags, test);
         }
     }
 }
 
-void
-SDL_EnumUnixAudioDevices(const int classic, int (*test)(int))
+void SDL_EnumUnixAudioDevices(const int classic, int (*test)(int))
 {
     SDL_EnumUnixAudioDevices_Internal(SDL_TRUE, classic, test);
     SDL_EnumUnixAudioDevices_Internal(SDL_FALSE, classic, test);
